<?php

namespace Drupal\personal_notes\Form;

use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 *
 */
class pn_addcontent extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'personal_notes_add_content';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, AccountInterface $user = NULL) {
    if (!\Drupal::currentUser()->isAnonymous() && !empty($user)) {
      $this->messenger()
        ->addMessage($this->t('Enter your title and note text to add a new note.'), 'status');
      $form['note_user'] = [
        '#type' => 'markup',
        '#markup' => "User: " . $user->getAccountName(),
      ];
      $form['note_title'] = [
        '#type' => 'textfield',
        '#title' => t('Note Title'),
        '#size' => 30,
        '#maxlength' => 24,
        '#required' => TRUE,
      ];
      $form['note_content'] = [
        '#type' => 'textarea',
        '#title' => t('Note Content'),
        '#rows' => 3,
        '#cols' => 40,
        '#resizable' => TRUE,
        '#required' => TRUE,
      ];
      $form['note_member'] = [
        '#type' => 'hidden',
        '#value' => $user->id(),
      ];
      $form['actions']['#type'] = 'actions';
      $form['actions']['submit'] = [
        '#type' => 'submit',
        '#value' => $this->t('Save'),
        '#button_type' => 'primary',
      ];
      return $form;
    }
    else {
      $this->messenger()
        ->addMessage($this->t('Please log on in order to add personal notes.'), 'status');
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Retrieve field data from triggered user.
    $uid = $form_state->getValues()['note_member'];
    $title = $form_state->getValues()['note_title'];
    $note = $form_state->getValues()['note_content'];
    $time = \Drupal::time()->getCurrentTime();

    $fields = [
      'uid' => $uid,
      'title' => $this->t($title),
      'note' => $this->t($note),
      'created' => $time,
    ];
    // Add new note to the database.
    \Drupal::database()->insert('personal_notes_notes')
      ->fields($fields)
      ->execute();
    $this->messenger()->addMessage($this->t('Your note was added.'), 'status');
  }

}
