<?php

namespace Drupal\personal_notes\Plugin\Block;

use Drupal\Core\Block\BlockBase;

/**
 * Creates a 'personal_notes' Block.
 *
 * @Block(
 *   id = "block_personal_notesblk",
 *   admin_label = @Translation("personal_notesblock"),
 * )
 */
class PersonalNotesBlock extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function build() {
    // User must be logged on to have personal notes.
    if (!\Drupal::currentUser()->isAnonymous()) {
      // Get their notes.
      $results = _personal_notes_fetch_content_db();
      $notedata = [];
      $notes = [];
      foreach ($results as $result) {
        foreach ($result as $field => $value) {
          if (preg_match('/^(title)|(note)|(created)|(notenum)$/', $field)) {
            // Save note's number, title and message.
            $notedata[$field] = $value;
          }
        }
        $notes[$notedata['title'] .
        str_pad(
          $notedata['notenum'],
          5,
          '0',
          STR_PAD_LEFT
        // Gives a constant length index display in the title.
        // Serialize the data.
        )] =
          // Store in a twig template friendly array.
          [
            'note' => $notedata['note'],
            'created' => date("F d, Y", $notedata['created']),
          ];
      }
      $build = [
        '#theme' => 'block--personal_notes',
        '#notes' => $notes,
        // Attach the stylesheet library.
        '#attached' => [
          'library' => [
            'personal_notes/personal_notes',
          ],
        ],
      ];
      return $build;
    }                                                            //    end if user is logged in
  }                                                                //    end build method

}
